# xray-cfo

A simple Python package for Xray-core functionality.

## Installation

You can install `xray-cfo` using pip:

```bash
pip install xray-cfo
```

Or with uv for faster installation:
```bash
uv pip install xray-cfo

```

